@@ -55,13 +55,10 @@ class CachedInstanceLoader(ModelInstanceLoader):
         self.all_instances = {}
         if self.dataset.dict and self.pk_field.column_name in self.dataset.dict[0]:
             ids = [self.pk_field.clean(row) for row in self.dataset.dict]
-            qs = self.get_queryset().filter(**{
-                "%s__in" % self.pk_field.attribute: ids
-                })
+            qs = self.get_queryset().filter(**{"%s__in" % self.pk_field.attribute: ids})
 
             self.all_instances = {
-                self.pk_field.get_value(instance): instance
-                for instance in qs
+                self.pk_field.get_value(instance): instance for instance in qs
             }
 
     def get_instance(self, row):
