@@ -5,17 +5,20 @@ from import_export.admin import (
     ImportExportModelAdmin,
     ImportMixin,
 )
+from import_export.fields import Field
 from import_export.resources import ModelResource
 
 from .forms import CustomConfirmImportForm, CustomExportForm, CustomImportForm
-from .models import Author, Book, Category, Child, EBook, LegacyBook
+from .models import Author, Book, Category, Child, EBook, UUIDBook, UUIDCategory
 
 
+@admin.register(Child)
 class ChildAdmin(ImportMixin, admin.ModelAdmin):
     pass
 
 
 class BookResource(ModelResource):
+
     class Meta:
         model = Book
 
@@ -30,6 +33,7 @@ class BookNameResource(ModelResource):
         name = "Export/Import only book names"
 
 
+@admin.register(Book)
 class BookAdmin(ImportExportModelAdmin):
     list_display = ("name", "author", "added")
     list_filter = ["categories", "author"]
@@ -37,28 +41,51 @@ class BookAdmin(ImportExportModelAdmin):
     change_list_template = "core/admin/change_list.html"
 
 
+@admin.register(Category)
 class CategoryAdmin(ExportActionModelAdmin):
-    def export_admin_action(self, request, queryset):
-        return super().export_admin_action(request, queryset)
+    def get_queryset(self, request):
+        return Category.objects.all()
 
 
+@admin.register(UUIDBook)
+class UUIDBookAdmin(ImportExportModelAdmin):
+    pass
+
+
+@admin.register(UUIDCategory)
+class UUIDCategoryAdmin(ExportActionModelAdmin):
+    pass
+
+
+@admin.register(Author)
 class AuthorAdmin(ImportMixin, admin.ModelAdmin):
     pass
 
 
+class UUIDBookResource(ModelResource):
+    class Meta:
+        model = UUIDBook
+
+
 class EBookResource(ModelResource):
+    published = Field(attribute="published", column_name="published_date")
+    author_email = Field(attribute="author_email", column_name="Email of the author")
+    auteur_name = Field(attribute="author__name", column_name="Author Name")
+
     def __init__(self, **kwargs):
         super().__init__()
         self.author_id = kwargs.get("author_id")
 
-    def filter_export(self, queryset, *args, **kwargs):
+    def filter_export(self, queryset, **kwargs):
         return queryset.filter(author_id=self.author_id)
 
     class Meta:
         model = EBook
+        fields = ("id", "author_email", "name", "published", "auteur_name")
 
 
-class CustomBookAdmin(ImportExportModelAdmin):
+@admin.register(EBook)
+class CustomBookAdmin(ExportActionModelAdmin, ImportExportModelAdmin):
     """Example usage of custom import / export forms"""
 
     resource_classes = [EBookResource]
@@ -74,48 +101,22 @@ class CustomBookAdmin(ImportExportModelAdmin):
             initial["author"] = import_form.cleaned_data["author"].id
         return initial
 
-    def get_import_resource_kwargs(self, request, *args, **kwargs):
+    def get_import_resource_kwargs(self, request, **kwargs):
         # update resource kwargs so that the Resource is passed the authenticated user
         # This is included as an example of how dynamic values
         # can be passed to resources
-        kwargs = super().get_resource_kwargs(request, *args, **kwargs)
+        if "form" not in kwargs:
+            # test for #1789
+            raise ValueError("'form' param was expected in kwargs")
+        kwargs = super().get_resource_kwargs(request, **kwargs)
         kwargs.update({"user": request.user})
         return kwargs
 
-    def get_export_resource_kwargs(self, request, *args, **kwargs):
+    def get_export_resource_kwargs(self, request, **kwargs):
         # this is overridden to demonstrate that custom form fields can be used
         # to override the export query.
         # The dict returned here will be passed as kwargs to EBookResource
-        export_form = kwargs["export_form"]
+        export_form = kwargs.get("export_form")
         if export_form:
-            return dict(author_id=export_form.cleaned_data["author"].id)
-        return {}
-
-
-class LegacyBookAdmin(BookAdmin):
-    """
-    BookAdmin with deprecated function overrides.
-    This class exists solely to test import works correctly using the deprecated
-    functions.
-    This class can be removed when the deprecated code is removed.
-    """
-
-    def get_import_form(self):
-        return super().get_import_form()
-
-    def get_confirm_import_form(self):
-        return super().get_confirm_import_form()
-
-    def get_form_kwargs(self, form, *args, **kwargs):
-        return super().get_form_kwargs(form, *args, **kwargs)
-
-    def get_export_form(self):
-        return super().get_export_form()
-
-
-admin.site.register(Book, BookAdmin)
-admin.site.register(Category, CategoryAdmin)
-admin.site.register(Author, AuthorAdmin)
-admin.site.register(Child, ChildAdmin)
-admin.site.register(EBook, CustomBookAdmin)
-admin.site.register(LegacyBook, LegacyBookAdmin)
+            kwargs.update(author_id=export_form.cleaned_data["author"].id)
+        return kwargs
