@@ -7,9 +7,11 @@ from django.views.generic import RedirectView
 admin.autodiscover()
 
 urlpatterns = [
-    path('', RedirectView.as_view(url='/admin/'), name="admin-site"),
-    path('admin/', admin.site.urls),
-    path('export/category/', views.CategoryExportView.as_view(), name='export-category'),
+    path("", RedirectView.as_view(url="/admin/"), name="admin-site"),
+    path("admin/", admin.site.urls),
+    path(
+        "export/category/", views.CategoryExportView.as_view(), name="export-category"
+    ),
 ]
 
 urlpatterns += staticfiles_urlpatterns()
